pub fn load_env(project_path: FileSystemPath) -> Vc<Box<dyn ProcessEnv>>Expand description
Loads a series of dotenv files according to the precedence rules set by Next.js.
pub fn load_env(project_path: FileSystemPath) -> Vc<Box<dyn ProcessEnv>>Loads a series of dotenv files according to the precedence rules set by Next.js.